@@ -136,7 +136,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="mainwindow.ui" line="590"/>
-        <location filename="mainwindow.cpp" line="275"/>
+        <location filename="mainwindow.cpp" line="285"/>
         <source>About</source>
         <translation>Informazioni</translation>
     </message>
@@ -227,7 +227,7 @@ p, li { white-space: pre-wrap; }
         <translation>Lista preferiti</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="451"/>
+        <location filename="mainwindow.cpp" line="461"/>
         <source>DoNotFilter</source>
         <translation>Nessun filtro</translation>
     </message>
@@ -237,37 +237,37 @@ p, li { white-space: pre-wrap; }
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="92"/>
+        <location filename="mainwindow.cpp" line="100"/>
         <source>&lt;b&gt;Playing:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;In esecuzione:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="118"/>
+        <location filename="mainwindow.cpp" line="128"/>
         <source>&lt;b&gt;Genre:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Genere:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="126"/>
+        <location filename="mainwindow.cpp" line="136"/>
         <source>&lt;b&gt;Bitrate:&lt;/b&gt; %1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="134"/>
+        <location filename="mainwindow.cpp" line="144"/>
         <source>&lt;b&gt;Location:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Posizione:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="142"/>
+        <location filename="mainwindow.cpp" line="152"/>
         <source>&lt;b&gt;Audio codec:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Codec audio:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="192"/>
+        <location filename="mainwindow.cpp" line="202"/>
         <source>No lyric found</source>
         <translation>Nessun testo trovato</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="211"/>
+        <location filename="mainwindow.cpp" line="221"/>
         <source>Loading lyrics...</source>
         <translation>Sto cercando il testo...</translation>
     </message>
@@ -281,73 +281,73 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt; {2&gt;?} {0.0.8&lt;?} {2&gt;?} {88@?} {88@?}</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="276"/>
+        <location filename="mainwindow.cpp" line="286"/>
         <source>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
         <translation>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="287"/>
-        <location filename="mainwindow.cpp" line="289"/>
-        <location filename="mainwindow.cpp" line="291"/>
-        <location filename="mainwindow.cpp" line="293"/>
+        <location filename="mainwindow.cpp" line="297"/>
+        <location filename="mainwindow.cpp" line="299"/>
+        <location filename="mainwindow.cpp" line="301"/>
+        <location filename="mainwindow.cpp" line="303"/>
         <source>New Station</source>
         <translation>Nuova stazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="287"/>
-        <location filename="mainwindow.cpp" line="315"/>
+        <location filename="mainwindow.cpp" line="297"/>
+        <location filename="mainwindow.cpp" line="325"/>
         <source>Insert Name: </source>
         <translation>Inserisci nome:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="289"/>
-        <location filename="mainwindow.cpp" line="317"/>
+        <location filename="mainwindow.cpp" line="299"/>
+        <location filename="mainwindow.cpp" line="327"/>
         <source>Insert Url: </source>
         <translation>Inserisci Indirizzo:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="291"/>
-        <location filename="mainwindow.cpp" line="319"/>
+        <location filename="mainwindow.cpp" line="301"/>
+        <location filename="mainwindow.cpp" line="329"/>
         <source>Insert Genre: </source>
         <translation>Inserisci Genere:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="293"/>
-        <location filename="mainwindow.cpp" line="321"/>
+        <location filename="mainwindow.cpp" line="303"/>
+        <location filename="mainwindow.cpp" line="331"/>
         <source>Insert Country: </source>
         <translation>Inserisci il Paese:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="315"/>
-        <location filename="mainwindow.cpp" line="317"/>
-        <location filename="mainwindow.cpp" line="319"/>
-        <location filename="mainwindow.cpp" line="321"/>
+        <location filename="mainwindow.cpp" line="325"/>
+        <location filename="mainwindow.cpp" line="327"/>
+        <location filename="mainwindow.cpp" line="329"/>
+        <location filename="mainwindow.cpp" line="331"/>
         <source>Edit Station</source>
         <translation>Modifica la stazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="339"/>
-        <location filename="mainwindow.cpp" line="472"/>
+        <location filename="mainwindow.cpp" line="349"/>
+        <location filename="mainwindow.cpp" line="482"/>
         <source>Internet Radio Widget</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="340"/>
+        <location filename="mainwindow.cpp" line="350"/>
         <source>Do you really want to delete the chosen station?</source>
         <translation>Vuoi veramente cancellare la stazione evidenziata?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="452"/>
+        <location filename="mainwindow.cpp" line="462"/>
         <source>FilterList</source>
         <translation>Filtra lista</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="453"/>
+        <location filename="mainwindow.cpp" line="463"/>
         <source>ManageFavourites</source>
         <translation>Gestisci preferiti</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="473"/>
+        <location filename="mainwindow.cpp" line="483"/>
         <source>This will clear your stations list.&lt;p&gt;Do you really want to continue?</source>
         <translation>Questo azzererà la tua lista stazioni.&lt;p&gt;Vuoi veramente continuare?</translation>
     </message>
@@ -364,17 +364,32 @@ p, li { white-space: pre-wrap; }
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="53"/>
+        <location filename="settingsdialog.ui" line="62"/>
         <source>Application Icon</source>
         <translation>Icona App</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="144"/>
+        <location filename="settingsdialog.ui" line="156"/>
         <source>Hide when closing</source>
         <translation>Nascondi invece di uscire</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="187"/>
+        <location filename="settingsdialog.ui" line="170"/>
+        <source>Show notifications</source>
+        <translation>Mostra notifiche</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="182"/>
+        <source>Notifications only when screen is not locked</source>
+        <translation>Notifiche solo quando lo schermo non è bloccato</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="194"/>
+        <source>Notifications only when window is not active or view is not PlayingNow</source>
+        <translation>Notifiche solo quando la finestra non è attiva o la vista non è InEsecuzione</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="241"/>
         <source>Save</source>
         <translation>Salva</translation>
     </message>
