@@ -9,6 +9,11 @@ int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
 
+    QPixmap pixmap(300, 43);
+    QSplashScreen splash(pixmap);
+    splash.show();
+    splash.showMessage("Loading translation", Qt::AlignHCenter, Qt::white);
+
     QString locale = QLocale::system().name();
     qDebug()<<"locale: "<<locale;
     QTranslator translator;
@@ -18,7 +23,14 @@ int main(int argc, char *argv[])
     a.setApplicationName("InternetRadioPlayer");
     a.setOrganizationName("GGiovanni88");
 
+    splash.showMessage("Loading interface", Qt::AlignHCenter, Qt::white);
+
     MainWindow w;
+    splash.showMessage("Loading stations", Qt::AlignHCenter, Qt::white);
+    w.loadStationsList();
+    w.populateList();
+
+    splash.showMessage("Settings dbus connections", Qt::AlignHCenter, Qt::white);
 
     if (!QDBusConnection::sessionBus().isConnected()) {
         qWarning("Cannot connect to the D-Bus session bus.");
@@ -39,6 +51,7 @@ int main(int argc, char *argv[])
     }
 
     w.show();
+    splash.finish(&w);
 
 
     return a.exec();
