@@ -3,7 +3,13 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "1.0.8";
+const QString appVersion = "1.0.9";
+
+void maemoBanner(QString string)
+{
+    QString program = "dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"" + string + "\"";
+    system(program.toStdString().c_str());
+}
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent), ui(new Ui::MainWindow), quitActionPressed(false), hideWhenClosing(false)
@@ -13,6 +19,8 @@ MainWindow::MainWindow(QWidget *parent) :
 
     ui->setupUi(this);
 
+    readSettings();
+
     mediaPlayer = new QMediaPlayer(this, QMediaPlayer::StreamPlayback);
 
     stationsDb.checkDB();
@@ -91,10 +99,12 @@ void MainWindow::getMetaData()
 
             ui->playingLabel->setText(QString(tr("<b>Playing:</b> %1")).arg(title));
 
-            QString command(QString("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Playing '%1'\"").arg(extn_metadata_value.toString()));
-            system(command.toStdString().c_str());
-            //    labelBox.setText("Playing '" + extn_metadata_value.toString() + "'");
-            //    infoBox.show();
+            //Notifications Management
+            if ( hasToShowNotifications() )
+            {
+                QString command(QString("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Playing '%1'\"").arg(extn_metadata_value.toString()));
+                system(command.toStdString().c_str());
+            }
 
 
             QFile file( "/home/user/MyDocs/.documents/InternetRadioPlayerLog.txt" );
@@ -623,6 +633,7 @@ void MainWindow::on_lyricsWebViewButton_clicked()
 void MainWindow::on_actionSettings_triggered()
 {
     SettingsDialog dialog;
+    connect(&dialog, SIGNAL(saveButtonClicked()), this, SLOT(settingsChanged()));
     dialog.exec();
 }
 
@@ -634,7 +645,7 @@ int MainWindow::top_application()
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
-    QSettings settings("InternetRadioPlayer", "Settings");
+    QSettings settings("internetradioplayer", "settings");
     hideWhenClosing = settings.value("hideWhenClosing", true).toBool();
 
     if ( !hideWhenClosing )
@@ -817,6 +828,66 @@ void MainWindow::quit()
     on_actionQuit_triggered();
 }
 
+void MainWindow::readSettings()
+{
+    QSettings settings("internetradioplayer", "settings");
+
+    showNotifications = settings.value("showNotifications", true ).toBool();
+    showNotificationsOnlyWhenScreenIsOn = settings.value("showNotificationsOnlyWhenScreenIsOn", true ).toBool();
+    showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow = settings.value("showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow", true ).toBool();
+}
+
+bool MainWindow::hasToShowNotifications()
+{
+    if ( !showNotifications )
+    {
+        return false;
+    }
+
+    if ( showNotificationsOnlyWhenScreenIsOn )
+    {
+        if ( isScreenLocked() )
+        {
+            //Option is on and screen is locked, not playing notifications so
+            return false;
+        }
+    }
+
+    if ( showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow)
+    {
+        qDebug() << "showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow: " << showNotificationsOnlyWhenWindowIsActiveOrViewNotPlayingNow;
+
+        if ( isActiveWindow() && ( ui->stackedWidget->currentIndex() == 0 ) )
+        {
+            //Option is on and: if screen is not active OR view is not PlayingNow, than it will continue, otherwise return false;
+            return false;
+        }
+    }
+
+    return true;
+
+
+}
+
+bool MainWindow::isScreenLocked()
+{
+    QFile file("/sys/class/backlight/acx565akm/brightness");
+
+    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    QTextStream in(&file);
+    QString string;
+    string = in.readLine();
+    //qDebug()<<"string = "<<string;
+
+    if (string == "0") return true;
+    else return false;
+}
+
+void MainWindow::settingsChanged()
+{
+    readSettings();
+}
+
 
 
 
