@@ -86,7 +86,7 @@ void StationsDB::restoreDefaultDB()
 QStringList StationsDB::getGenreList()
 {
     QSqlQuery query( db );
-    query.exec("SELECT DISTINCT genre FROM stations ORDER BY name");
+    query.exec("SELECT DISTINCT genre FROM stations ORDER BY genre");
 
     QStringList genreList;
     while (query.next())
@@ -100,7 +100,7 @@ QStringList StationsDB::getGenreList()
 QStringList StationsDB::getCountryList()
 {
     QSqlQuery query( db );
-    query.exec("SELECT DISTINCT country FROM stations ORDER BY name");
+    query.exec("SELECT DISTINCT country FROM stations ORDER BY country");
 
     QStringList countryList;
     while (query.next())
@@ -345,6 +345,8 @@ void StationsDB::addDefaultStations()
     query.exec(QString("INSERT INTO \"stations\" VALUES('USA','Electronic','DigitallyImported Synthpop','http://80.94.69.106:6234/',0);"));
     query.exec(QString("INSERT INTO \"stations\" VALUES('USA','House','DigitallyImported Electro House','http://scfire-dtc-aa03.stream.aol.com:80/stream/1025',0);"));
     query.exec(QString("INSERT INTO \"stations\" VALUES('USA','Electronic','DigitallyImported Lounge','http://scfire-ntc-aa02.stream.aol.com:80/stream/1009',0);"));
+    query.exec(QString("INSERT INTO \"stations\" VALUES('USA','Progressive','Beyond Ear Candy','http://216.66.69.100:6294/',0);"));
+
 }
 
 
